==> ramda-0.1.2.tgz: package/ramda.api.js <==
// copy(map(function(key) {return ["var " + key + " = function() {};"].concat(map(function(sub) {return "    " + key + "." + sub + " = function() {};"}, keys(ramda[key])));}, keys(ramda)).sort(function(a, b) {var x = toLowerCase(a.substring(4)), y = toLowerCase(b.substring(4)); return x < y ? -1 : x > y ? 1 : 0;}).join("\n"));

var add = function() {};
var all = function() {};
var allPredicates = function() {};
var always = function() {};
var alwaysFalse = function() {};
var alwaysTrue = function() {};
var alwaysZero = function() {};
var and = function() {};
var andFn = function() {};
var any = function() {};
var anyPredicates = function() {};
var append = function() {};
var applyLeft = function() {};
var applyRight = function() {};
var arity = function() {};
var car = function() {};
var cdr = function() {};
var charAt = function() {};
var charCodeAt = function() {};
var clone = function() {};
var cloneDeep = function() {};
var comparator = function() {};
var compose = function() {};
var concat = function() {};
var cons = function() {};
var construct = function() {};
var contains = function() {};
var countBy = function() {};
var curry = function() {};
var difference = function() {};
var differenceWith = function() {};
var divide = function() {};
var divideBy = function() {};
var drop = function() {};
var each = function() {};
    each.idx = function() {};
var eq = function() {};
var eqProps = function() {};
var every = function() {};
var filter = function() {};
    filter.idx = function() {};
var find = function() {};
var findIndex = function() {};
var findLast = function() {};
var findLastIndex = function() {};
var flatten = function() {};
var flip = function() {};
var foldl = function() {};
    foldl.idx = function() {};
var foldl1 = function() {};
var foldr = function() {};
    foldr.idx = function() {};
var foldr1 = function() {};
var forEach = function() {};
    forEach.idx = function() {};
var func = function() {};
var generator = function() {};
var get = function() {};
var groupBy = function() {};
var gt = function() {};
var gte = function() {};
var head = function() {};
var I = function() {};
var identity = function() {};
var indexOf = function() {};
var installTo = function() {};
var intersection = function() {};
var intersectionWith = function() {};
var invoker = function() {};
var isAtom = function() {};
var isEmpty = function() {};
var isSet = function() {};
var join = function() {};
var K = function() {};
var keys = function() {};
var lastIndexOf = function() {};
var lPartial = function() {};
var lt = function() {};
var lte = function() {};
var map = function() {};
    map.idx = function() {};
var match = function() {};
var max = function() {};
var maxWith = function() {};
var maybe = function() {};
var memoize = function() {};
var merge = function() {};
var min = function() {};
var minWith = function() {};
var mixin = function() {};
var multiply = function() {};
var nAry = function() {};
var not = function() {};
var notFn = function() {};
var nth = function() {};
var omit = function() {};
var once = function() {};
var or = function() {};
var orFn = function() {};
var pick = function() {};
var pickAll = function() {};
var pipe = function() {};
var pluck = function() {};
var prepend = function() {};
var product = function() {};
var project = function() {};
var prop = function() {};
var propEq = function() {};
var props = function() {};
var push = function() {};
var range = function() {};
var reduce = function() {};
    reduce.idx = function() {};
var reduceRight = function() {};
    reduceRight.idx = function() {};
var reject = function() {};
    reject.idx = function() {};
var repeat = function() {};
    repeat.nTimes = function() {};
var reverse = function() {};
var rPartial = function() {};
var sequence = function() {};
var size = function() {};
var skip = function() {};
var skipUntil = function() {};
var some = function() {};
var sort = function() {};
var sortBy = function() {};
var splice = function() {};
var split = function() {};
var strIndexOf = function() {};
var strLastIndexOf = function() {};
var substring = function() {};
var substringFrom = function() {};
var substringTo = function() {};
var subtract = function() {};
var subtractN = function() {};
var sum = function() {};
var tail = function() {};
var take = function() {};
var takeWhile = function() {};
var tap = function() {};
var toLowerCase = function() {};
var toUpperCase = function() {};
var unfoldr = function() {};
var union = function() {};
var unionWith = function() {};
var uniq = function() {};
var use = function() {};
var useWith = function() {};
var values = function() {};
var where = function() {};
var wrap = function() {};
var xprod = function() {};
var xprodWith = function() {};
var zip = function() {};
var zipWith = function() {};

==> ramda-0.1.5.tgz: package/ramda.api.js <==
/*
copy(flatten(map(function (key) {
    return ["var " + key + " = function() {};"].concat(map(function (sub) {
        return "    " + key + "." + sub + " = function() {};"
    }, keys(ramda[key])));
}, keys(ramda))).sort(function (a, b) {
    var x = toLowerCase(a.substring(4)),
            y = toLowerCase(b.substring(4));
    return x < y ? -1 : x > y ? 1 : 0;
}).join("\n"));
*/

var add = function() {};
var all = function() {};
var allPredicates = function() {};
var always = function() {};
var alwaysFalse = function() {};
var alwaysTrue = function() {};
var alwaysZero = function() {};
var and = function() {};
var any = function() {};
var anyPredicates = function() {};
var append = function() {};
var applyLeft = function() {};
var applyRight = function() {};
var arity = function() {};
var car = function() {};
var cdr = function() {};
var charAt = function() {};
var charCodeAt = function() {};
var clone = function() {};
var cloneDeep = function() {};
var comparator = function() {};
var compose = function() {};
var concat = function() {};
var cons = function() {};
var construct = function() {};
var contains = function() {};
var countBy = function() {};
var curry = function() {};
var difference = function() {};
var differenceWith = function() {};
var divide = function() {};
var divideBy = function() {};
var drop = function() {};
var each = function() {};
    each.idx = function() {};
var eq = function() {};
var eqProps = function() {};
var every = function() {};
var filter = function() {};
    filter.idx = function() {};
var find = function() {};
var findIndex = function() {};
var findLast = function() {};
var findLastIndex = function() {};
var first = function() {};
var flatten = function() {};
var flip = function() {};
var foldl = function() {};
    foldl.idx = function() {};
var foldl1 = function() {};
var foldr = function() {};
    foldr.idx = function() {};
var foldr1 = function() {};
var forEach = function() {};
    forEach.idx = function() {};
var fork = function() {};
var func = function() {};
var get = function() {};
var groupBy = function() {};
var gt = function() {};
var gte = function() {};
var head = function() {};
var I = function() {};
var identity = function() {};
var indexOf = function() {};
var installTo = function() {};
var intersection = function() {};
var intersectionWith = function() {};
var invoker = function() {};
var isAtom = function() {};
var isEmpty = function() {};
var isSet = function() {};
var join = function() {};
var K = function() {};
var keys = function() {};
var last = function() {};
var lastIndexOf = function() {};
var lazylist = function() {};
var lPartial = function() {};
var lt = function() {};
var lte = function() {};
var map = function() {};
    map.idx = function() {};
var mapObj = function() {};
var match = function() {};
var max = function() {};
var maxWith = function() {};
var memoize = function() {};
var merge = function() {};
var min = function() {};
var minWith = function() {};
var mixin = function() {};
var modulo = function() {};
var moduloBy = function() {};
var multiply = function() {};
var nAry = function() {};
var not = function() {};
var nth = function() {};
var omit = function() {};
var once = function() {};
var or = function() {};
var partition = function() {};
var pick = function() {};
var pickAll = function() {};
var pipe = function() {};
var pluck = function() {};
var prepend = function() {};
var product = function() {};
var project = function() {};
var prop = function() {};
var propEq = function() {};
var props = function() {};
var push = function() {};
var range = function() {};
var reduce = function() {};
    reduce.idx = function() {};
var reduceRight = function() {};
    reduceRight.idx = function() {};
var reject = function() {};
    reject.idx = function() {};
var repeat = function() {};
var repeatN = function() {};
var reverse = function() {};
var rPartial = function() {};
var sequence = function() {};
var size = function() {};
var skip = function() {};
var skipUntil = function() {};
var slice = function() {};
    slice.from = function() {};
var some = function() {};
var sort = function() {};
var sortBy = function() {};
var splice = function() {};
var split = function() {};
var strIndexOf = function() {};
var strLastIndexOf = function() {};
var substring = function() {};
var substringFrom = function() {};
var substringTo = function() {};
var subtract = function() {};
var subtractN = function() {};
var sum = function() {};
var tail = function() {};
var take = function() {};
var takeWhile = function() {};
var tap = function() {};
var toLowerCase = function() {};
var toUpperCase = function() {};
var unfoldr = function() {};
var union = function() {};
var unionWith = function() {};
var uniq = function() {};
var use = function() {};
var useWith = function() {};
var values = function() {};
var where = function() {};
var wrap = function() {};
var xprod = function() {};
var xprodWith = function() {};
var zip = function() {};
var zipWith = function() {};
